@@ -44,7 +44,7 @@ def replace_header_items(ps, replacments):
         if match is not None:
             key = match.groupdict()['key']
             if key in replacments:
-                ps.current_line = match.expand('\g<key>\g<space>%s\n' % replacments[key])
+                ps.current_line = match.expand('\\g<key>\\g<space>%s\n' % replacments[key])
         ps.read_line()
 
 
@@ -59,7 +59,7 @@ def parse(ps, header_replacements, body_replacements):
                 key = match.groupdict()['id']
                 if key in body_replacements:
                     value = body_replacements[key].target or body_replacements[key].source
-                    ps.current_line = match.expand(u'\g<start>\g<id>\g<space>%s\n' % escape(value))
+                    ps.current_line = match.expand(u'\\g<start>\\g<id>\\g<space>%s\n' % escape(value))
             ps.read_line()
     except StopIteration:
         pass
