@@ -23,6 +23,7 @@ files, preserving existing translations.
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/pot2po.html
 for examples and usage instructions.
 """
+from __future__ import unicode_literals
 
 import six
 
@@ -34,7 +35,7 @@ from translate.tools import pretranslate
 
 def convertpot(input_file, output_file, template_file, tm=None,
                min_similarity=75, fuzzymatching=True, classes=None,
-               classes_str=factory.classes_str, **kwargs):
+               classes_str=None, **kwargs):
     """Main conversion function."""
     input_store = factory.getobject(input_file, classes=classes,
                                     classes_str=classes_str)
@@ -122,9 +123,11 @@ def _store_pre_merge(input_store, output_store, template_store, **kwargs):
     if isinstance(input_store, poheader.poheader):
         _do_poheaders(input_store, output_store, template_store)
     elif isinstance(input_store, catkeys.CatkeysFile):
-        #FIXME: shouldn't we be merging template_store.header instead?
         #FIXME: also this should be a format specific hook
-        output_store.header = input_store.header
+        if template_store is not None:
+            output_store.header = template_store.header
+        else:
+            output_store.header = input_store.header
 
     # Dispatch to format specific functions
     store_pre_merge_hook = "_store_pre_merge_%s" % input_store.__class__.__name__
