@@ -2,7 +2,7 @@
 
 from translate.convert import php2po, test_convert
 from translate.misc import wStringIO
-from translate.storage import php, po
+from translate.storage import po
 
 
 class TestPhp2PO(object):
@@ -10,22 +10,22 @@ class TestPhp2PO(object):
     def php2po(self, phpsource, phptemplate=None):
         """helper that converts .php source to po source without requiring files"""
         inputfile = wStringIO.StringIO(phpsource)
-        inputphp = php.phpfile(inputfile)
-        convertor = php2po.php2po()
+        output_file = wStringIO.StringIO()
+        templatefile = None
         if phptemplate:
             templatefile = wStringIO.StringIO(phptemplate)
-            templatephp = php.phpfile(templatefile)
-            outputpo = convertor.mergestore(templatephp, inputphp)
-        else:
-            outputpo = convertor.convertstore(inputphp)
-        return outputpo
+        convertor = php2po.php2po(inputfile, output_file, templatefile)
+        convertor.run()
+        return convertor.target_store
 
-    def convertphp(self, phpsource):
-        """call the convertphp, return the outputfile"""
+    def convertphp(self, phpsource, template=None, expected=1):
+        """call run_converter, return the outputfile"""
         inputfile = wStringIO.StringIO(phpsource)
         outputfile = wStringIO.StringIO()
         templatefile = None
-        assert php2po.convertphp(inputfile, outputfile, templatefile)
+        if template:
+            templatefile = wStringIO.StringIO(template)
+        assert php2po.run_converter(inputfile, outputfile, templatefile) == expected
         return outputfile.getvalue()
 
     def singleelement(self, pofile):
@@ -58,6 +58,34 @@ class TestPhp2PO(object):
         assert pounit.source == "entry"
         assert pounit.target == ""
 
+    def test_convertphptemplate(self):
+        """checks that the convertphp function is working with template"""
+        phpsource = """$_LANG['simple'] = 'entry';"""
+        phptemplate = '''$_LANG['simple'] = 'source';'''
+        posource = self.convertphp(phpsource, phptemplate)
+        pofile = po.pofile(wStringIO.StringIO(posource))
+        pounit = self.singleelement(pofile)
+        assert pounit.source == "source"
+        assert pounit.target == "entry"
+
+    def test_convertphpmissing(self):
+        """checks that the convertphp function is working with missing key"""
+        phpsource = """$_LANG['simple'] = 'entry';"""
+        phptemplate = '''$_LANG['missing'] = 'source';'''
+        posource = self.convertphp(phpsource, phptemplate)
+        pofile = po.pofile(wStringIO.StringIO(posource))
+        pounit = self.singleelement(pofile)
+        assert pounit.source == "source"
+        assert pounit.target == ""
+
+    def test_convertphpempty(self):
+        """checks that the convertphp function is working with empty template"""
+        phpsource = ''
+        phptemplate = ''
+        posource = self.convertphp(phpsource, phptemplate, 0)
+        pofile = po.pofile(wStringIO.StringIO(posource))
+        assert len(pofile.units) == 0
+
     def test_unicode(self):
         """checks that unicode entries convert properly"""
         unistring = u'Norsk bokm\u00E5l'
@@ -131,7 +159,7 @@ $lang['prefPanel-smime'] = 'Security';'''
     def test_spaces_in_name(self):
         """checks that if we have spaces in the name we create a good PO with no spaces"""
         phptemplate = '''$lang[ 'credit' ] = 'Something';'''
-        phpsource = '''$lang[ 'credit' ] = ''n Ding';'''
+        phpsource = '''$lang[ 'credit' ] = 'n Ding';'''
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$lang[ 'credit' ]"]
@@ -148,7 +176,7 @@ $lang['prefPanel-smime'] = 'Security';'''
         phpsource = '''return array(\n'id-1' => 'target-1',\n);'''
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
-        assert pounit.getlocations() == ["'id-1'"]
+        assert pounit.getlocations() == ["return->'id-1'"]
 
     def test_named_nested_arrays(self):
         phptemplate = '''$strings = array(
@@ -225,14 +253,14 @@ $lang['prefPanel-smime'] = 'Security';'''
         );'''
         pofile = self.php2po(phpsource, phptemplate)
         expected = {
-            "'name1'": ("source1", "target1"),
-            "'list1'->'l1'": ("source_l1_1", "target_l1_1"),
-            "'list1'->'l2'": ("source_l1_2", "target_l1_2"),
-            "'list1'->'l3'": ("source_l1_3", "target_l1_3"),
-            "'list2'->'l1'": ("source_l2_1", "target_l2_1"),
-            "'list2'->'l2'": ("source_l2_2", "target_l2_2"),
-            "'list2'->'l3'": ("source_l2_3", "target_l2_3"),
-            "'name2'": ("source2", "target2"),
+            "return->'name1'": ("source1", "target1"),
+            "return->'list1'->'l1'": ("source_l1_1", "target_l1_1"),
+            "return->'list1'->'l2'": ("source_l1_2", "target_l1_2"),
+            "return->'list1'->'l3'": ("source_l1_3", "target_l1_3"),
+            "return->'list2'->'l1'": ("source_l2_1", "target_l2_1"),
+            "return->'list2'->'l2'": ("source_l2_2", "target_l2_2"),
+            "return->'list2'->'l3'": ("source_l2_3", "target_l2_3"),
+            "return->'name2'": ("source2", "target2"),
         }
         for pounit in [x for x in pofile.units if x.source != '']:
             assert ((pounit.source, pounit.target) ==
@@ -244,9 +272,9 @@ class TestPhp2POCommand(test_convert.TestConvertCommand, TestPhp2PO):
     convertmodule = php2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
