@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2008,2010 Zuza Software Foundation
@@ -22,6 +21,7 @@
 """
 
 import re
+import six
 
 from translate.filters import decoration
 from translate.misc import quote
@@ -35,7 +35,7 @@ def removekdecomments(str1):
 
       "_: comment\n"
     """
-    assert isinstance(str1, unicode)
+    assert isinstance(str1, six.text_type)
     iskdecomment = False
     lines = str1.split("\n")
     removelines = []
@@ -83,7 +83,7 @@ def filteraccelerators(accelmarker):
 
 
 def varname(variable, startmarker, endmarker):
-    """Variable filter that returns the variable name without the marking
+    r"""Variable filter that returns the variable name without the marking
     punctuation.
 
     .. note:: Currently this function simply returns *variable* unchanged, no
@@ -134,8 +134,9 @@ def filtervariables(startmarker, endmarker, varfilter):
         endmarkerlen = len(endmarker)
 
     def filtermarkedvariables(str1):
-        """Modifies the variables in *str1* marked with a given *\*marker*,
-        using a given filter."""
+        r"""Modifies the variables in *str1* marked with a given *\*marker*,
+        using a given filter.
+        """
         varlocs = decoration.findmarkedvariables(str1, startmarker, endmarker)
         fstr1, pos = "", 0
         for varstart, variable in varlocs:
@@ -146,13 +147,14 @@ def filtervariables(startmarker, endmarker, varfilter):
         return fstr1
     return filtermarkedvariables
 
+
 # a list of special words with punctuation
 # all apostrophes in the middle of the word are handled already
-wordswithpunctuation = ["'n", "'t",]  # Afrikaans
+wordswithpunctuation = ["'n", "'t"]  # Afrikaans
 # map all the words to their non-punctified equivalent
-wordswithpunctuation = dict([(word, filter(str.isalnum, word)) for word in wordswithpunctuation])
+wordswithpunctuation = dict([(word, ''.join(filter(str.isalnum, word))) for word in wordswithpunctuation])
 
-word_with_apos_re = re.compile("(?u)\w+'\w+")
+word_with_apos_re = re.compile(r"(?u)\w+'\w+")
 
 
 def filterwordswithpunctuation(str1):
@@ -162,11 +164,11 @@ def filterwordswithpunctuation(str1):
     if u"'" not in str1:
         return str1
     occurrences = []
-    for word, replacement in wordswithpunctuation.iteritems():
+    for word, replacement in six.iteritems(wordswithpunctuation):
         occurrences.extend([(pos, word, replacement) for pos in quote.find_all(str1, word)])
     for match in word_with_apos_re.finditer(str1):
         word = match.group()
-        replacement = filter(unicode.isalnum, word)
+        replacement = ''.join(filter(six.text_type.isalnum, word))
         occurrences.append((match.start(), word, replacement))
     occurrences.sort()
     if occurrences:
