@@ -33,16 +33,14 @@ It is not completely working, but it should give you a good start.
 
 import re
 import six
-import sys
 from . import CommonIndexer
 import xapian
 import os
-import time
-import logging
 
 
 def is_available():
-    return xapian.major_version() > 0
+    # Gracefully handle mocking while building docs
+    return repr(xapian.major_version()) == "xapian.major_version" or xapian.major_version() > 0
 
 
 # in xapian there is a length restriction for term strings
@@ -374,23 +372,23 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
                                (result, fieldnames))
         return result
 
-    def _delete_stale_lock(self):
-        if not self._writer_is_open():
-            lockfile = os.path.join(self.location, 'flintlock')
-            if (os.path.exists(lockfile) and
-                (time.time() - os.path.getmtime(lockfile)) / 60 > 15):
-                logging.warning("Stale lock found in %s, removing.",
-                                self.location)
-                os.remove(lockfile)
-
     def _writer_open(self):
         """Open write access for the indexing database and acquire an
         exclusive lock.
         """
         if not self._writer_is_open():
-            self._delete_stale_lock()
             try:
                 self.writer = xapian.WritableDatabase(self.location, xapian.DB_OPEN)
+            except xapian.DatabaseLockError as err_msg:
+                # Do NOT delete the lock file - it's locked with fcntl()
+                # locking which the OS releases automatically when a
+                # process terminates so a "stale lock" is impossible.
+                # If it isn't in use, the failure will be some sort of
+                # system issue like running out of fds or processes.
+                raise ValueError("Indexer: failed to lock xapian database "
+                                 "(%s) for writing - it's probably in use "
+                                 "already: %s" %
+                                 (self.location, str(err_msg)))
             except xapian.DatabaseOpeningError as err_msg:
 
                 raise ValueError("Indexer: failed to open xapian database "
