@@ -28,14 +28,14 @@ import six
 from lxml import etree
 
 from translate.lang import data
+from translate.misc.deprecation import deprecated
+from translate.misc.xml_helpers import reindent
 from translate.storage import base, lisa
 from translate.misc.multistring import multistring
 
-from babel.core import Locale, UnknownLocaleError
-
 EOF = None
-WHITESPACE = ' \t'  # Whitespace that we collapse.
-MULTIWHITESPACE = re.compile('[ \t]{2}')
+WHITESPACE = ' \n\t'  # Whitespace that we collapse.
+MULTIWHITESPACE = re.compile('[ \n\t]{2}(?!\\\\n)')
 
 
 @six.python_2_unicode_compatible
@@ -46,7 +46,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def createfromxmlElement(cls, element):
         term = None
         # Actually this class supports only plurals and string tags
-        if ((element.tag == "plurals") or (element.tag == "string")):
+        if element.tag == "plurals" or element.tag == "string":
             term = cls(None, xmlelement=element)
         return term
 
@@ -58,7 +58,6 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.xmlelement = etree.Element("plurals")
             else:
                 self.xmlelement = etree.Element("string")
-            self.xmlelement.tail = '\n'
         if source is not None:
             self.setid(source)
         super(AndroidResourceUnit, self).__init__(source)
@@ -81,7 +80,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def getcontext(self):
         return self.xmlelement.get("name")
 
-    def unescape(self, text):
+    def unescape(self, text, strip=True):
         """
         Remove escaping from Android resource.
 
@@ -120,6 +119,8 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # non-significant newlines/tabs etc.
                         text[i-space_count:i] = ' '
                         i -= space_count - 1
+                        if strip and (i == 1 or c is EOF):
+                            del text[i-1]
                     space_count = 0
                 elif space_count == 1:
                     # At this point we have a single whitespace character,
@@ -129,6 +130,8 @@ class AndroidResourceUnit(base.TranslationUnit):
                     # make sure that this kind of whitespace is always a
                     # standard space.
                     text[i-1] = ' '
+                    if strip and not active_quote and (i == 1 or c is EOF):
+                        del text[i-1]
                     space_count = 0
                 else:
                     space_count = 0
@@ -176,7 +179,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                     elif c == ' ':
                         text[i-1:i+1] = ' '  # an actual space
                         i -= 1
-                    elif c in '"\'@':
+                    elif c in '"\'@?':
                         text[i-1:i] = ''  # remove the backslash
                         i -= 1
                     elif c == 'u':
@@ -230,8 +233,12 @@ class AndroidResourceUnit(base.TranslationUnit):
         if len(text) == 0:
             return ''
         text = text.replace('\\', '\\\\')
+        # This will add non intrusive real newlines to
+        # ones in translation improving readability of result
+        text = text.replace('\n', '\n\\n')
         text = text.replace('\t', '\\t')
         text = text.replace('\'', '\\\'')
+        text = text.replace('?', '\\?')
         text = text.replace('"', '\\"')
 
         # @ needs to be escaped at start
@@ -243,23 +250,65 @@ class AndroidResourceUnit(base.TranslationUnit):
             return '"%s"' % text
         return text
 
-    def setsource(self, source):
-        super(AndroidResourceUnit, self).setsource(source)
-
-    def getsource(self, lang=None):
-        if (super(AndroidResourceUnit, self).source is None):
+    @base.TranslationUnit.source.getter
+    def source(self):
+        if super(AndroidResourceUnit, self).source is None:
             return self.target
-        else:
-            return super(AndroidResourceUnit, self).source
+        return super(AndroidResourceUnit, self).source
 
-    source = property(getsource, setsource)
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
+
+    def get_xml_text_value(self, xmltarget):
+        if len(xmltarget) == 0:
+            # There are no html markups, so unescaping it as plain text.
+            return self.unescape(xmltarget.text)
+        else:
+            # There are html markups, so clone it to perform unescaping for all elements.
+            cloned_target = copy.deepcopy(xmltarget)
+
+            # Unescaping texts.
+            if cloned_target.text is not None:
+                cloned_target.text = self.unescape(cloned_target.text, False)
+            for xmlelement in cloned_target.iterdescendants():
+                if xmlelement.text is not None and xmlelement.tag is not etree.Entity:
+                    xmlelement.text = self.unescape(xmlelement.text, False)
+                if xmlelement.tail is not None:
+                    xmlelement.tail = self.unescape(xmlelement.tail, False)
+
+            # Grab root text (using a temporary xml element for text escaping)
+            if cloned_target.text is not None:
+                tmp_element = etree.Element('t')
+                tmp_element.text = cloned_target.text
+                target = data.forceunicode(etree.tostring(tmp_element, encoding='utf-8')[3:-4])
+            else:
+                target = u''
+
+            # Include markup as well
+            target += u''.join([data.forceunicode(etree.tostring(child, encoding='utf-8'))
+                                for child in cloned_target.iterchildren()])
+            return target
 
     def set_xml_text_value(self, target, xmltarget):
-        if '<' in target:
+        if '<' in target or '&' in target:
+            # Try to handle it as legacy XML
+            parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
+            if self._store is not None:
+                cloned_doc = copy.deepcopy(self._store.document)
+                cloned_root = cloned_doc.getroot()
+                for child in cloned_root.iterchildren():
+                    cloned_root.remove(child)
+                template = etree.tostring(cloned_doc, encoding='unicode')
+            else:
+                template = '<resources></resources>'
             try:
-                # Try to handle it as legacy XML
-                newstring = etree.fromstring('<string>%s</string>' % target)
-            except:
+                newstring = etree.fromstring(
+                    template.replace('</resources>', '<string>%s</string></resources>' % target),
+                    parser
+                )[0]
+            except Exception:
                 # Fallback to string with XML escaping
                 xmltarget.text = self.escape(target)
             else:
@@ -267,7 +316,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                 if newstring.text is not None:
                     newstring.text = self.escape(newstring.text, False)
                 for x in newstring.iterdescendants():
-                    if x.text is not None:
+                    if x.text is not None and x.tag is not etree.Entity:
                         x.text = self.escape(x.text, False)
                     if x.tail is not None:
                         x.tail = self.escape(x.tail, False)
@@ -282,27 +331,30 @@ class AndroidResourceUnit(base.TranslationUnit):
                 for x in newstring.iterchildren():
                     xmltarget.append(x)
         else:
+            # Remove possible old elements
+            for x in xmltarget.iterchildren():
+                xmltarget.remove(x)
             # Handle text only
             xmltarget.text = self.escape(target)
 
-    def settarget(self, target):
-        if (self.hasplurals(self.source) or self.hasplurals(target)):
+    @property
+    def target(self):
+        if self.xmlelement.tag != "plurals":
+            return self.get_xml_text_value(self.xmlelement)
+        return multistring([data.forceunicode(self.get_xml_text_value(entry))
+                            for entry in self.xmlelement.iterchildren('item')])
+
+    @target.setter
+    def target(self, target):
+        if self.hasplurals(self.source) or self.hasplurals(target):
             # Fix the root tag if mismatching
             if self.xmlelement.tag != "plurals":
                 old_id = self.getid()
                 self.xmlelement = etree.Element("plurals")
-                self.xmlelement.tail = '\n'
                 self.setid(old_id)
 
-            try:
-                lang_tags = set(Locale(self.gettargetlanguage()).plural_form.tags)
-            except UnknownLocaleError:
-                lang_tags = set(Locale('en').plural_form.tags)
-            # Ensure that the implicit default "other" rule is present (usually omitted by Babel)
-            lang_tags.add('other')
-
-            # Get plural tags in the right order.
-            plural_tags = [tag for tag in ['zero', 'one', 'two', 'few', 'many', 'other'] if tag in lang_tags]
+            locale = self.gettargetlanguage().replace('_', '-').split('-')[0]
+            plural_tags = data.plural_tags.get(locale, data.plural_tags['en'])
 
             # Get string list to handle, wrapping non multistring/list targets into a list.
             if isinstance(target, multistring):
@@ -321,68 +373,36 @@ class AndroidResourceUnit(base.TranslationUnit):
             for entry in self.xmlelement.iterchildren():
                 self.xmlelement.remove(entry)
 
-            self.xmlelement.text = "\n\t"
+            self.xmlelement.text = "\n    "
+
+            # Include "other" as copy of "many" if "other" is not present. This avoids crashes
+            # of Android builts with broken plurals handling.
+            if "other" not in plural_tags and "many" in plural_tags:
+                # Create copy here to avoid modifications to laguage.data
+                plural_tags = plural_tags + ["other"]
+                plural_strings.append(plural_strings[-1])
 
             for plural_tag, plural_string in zip(plural_tags, plural_strings):
                 item = etree.Element("item")
                 item.set("quantity", plural_tag)
                 self.set_xml_text_value(plural_string, item)
-                item.tail = "\n\t"
                 self.xmlelement.append(item)
-            # Remove the tab from last item
-            item.tail = "\n"
         else:
             # Fix the root tag if mismatching
             if self.xmlelement.tag != "string":
                 old_id = self.getid()
                 self.xmlelement = etree.Element("string")
-                self.xmlelement.tail = '\n'
                 self.setid(old_id)
 
             self.set_xml_text_value(target, self.xmlelement)
 
-        super(AndroidResourceUnit, self).settarget(target)
+        self._rich_target = None
+        self._target = target
 
-    def get_xml_text_value(self, xmltarget):
-        if (len(xmltarget) == 0):
-            # There are no html markups, so unescaping it as plain text.
-            return self.unescape(xmltarget.text)
-        else:
-            # There are html markups, so clone it to perform unescaping for all elements.
-            cloned_target = copy.deepcopy(xmltarget)
-
-            # Unescaping texts.
-            if (cloned_target.text is not None):
-                cloned_target.text = self.unescape(cloned_target.text)
-            for xmlelement in cloned_target.iterdescendants():
-                if (xmlelement.text is not None):
-                    xmlelement.text = self.unescape(xmlelement.text)
-                if (xmlelement.tail is not None):
-                    xmlelement.tail = self.unescape(xmlelement.tail)
-
-            # Grab root text (using a temporary xml element for text escaping)
-            if (cloned_target.text is not None):
-                tmp_element = etree.Element('t')
-                tmp_element.text = cloned_target.text
-                target = data.forceunicode(etree.tostring(tmp_element, encoding='utf-8')[3:-4])
-            else:
-                target = u''
-
-            # Include markup as well
-            target += u''.join([data.forceunicode(etree.tostring(child, encoding='utf-8'))
-                                for child in cloned_target.iterchildren()])
-            return target
-
-    def gettarget(self, lang=None):
-        if (self.xmlelement.tag == "plurals"):
-            target = []
-            for entry in self.xmlelement.iterchildren():
-                target.append(self.get_xml_text_value(entry))
-            return multistring(target)
-        else:
-            return self.get_xml_text_value(self.xmlelement)
-
-    target = property(gettarget, settarget)
+    # Deprecated on 2.3.1
+    @deprecated("Use `target` property instead")
+    def gettarget(self):
+        return self.target
 
     def getlanguageNode(self, lang=None, index=None):
         return self.xmlelement
@@ -399,7 +419,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def getnotes(self, origin=None):
         if origin in ['programmer', 'developer', 'source code', None]:
             comments = []
-            if (self.xmlelement is not None):
+            if self.xmlelement is not None:
                 prevSibling = self.xmlelement.getprevious()
                 while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
                     comments.insert(0, prevSibling.text)
@@ -409,7 +429,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         else:
             return super(AndroidResourceUnit, self).getnotes(origin)
 
-    def removenotes(self):
+    def removenotes(self, origin=None):
         if ((self.xmlelement is not None) and (self.xmlelement.getparent is not None)):
             prevSibling = self.xmlelement.getprevious()
             while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
@@ -444,6 +464,7 @@ class AndroidResourceFile(lisa.LISAfile):
     bodyNode = "resources"
     XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
 <resources></resources>'''
+    _doctype = None
 
     def initbody(self):
         """Initialises self.body so it never needs to be retrieved from the XML
@@ -452,6 +473,13 @@ class AndroidResourceFile(lisa.LISAfile):
         self.namespace = self.document.getroot().nsmap.get(None, None)
         self.body = self.document.getroot()
 
+    def serialize(self, out=None):
+        """Converts to a string containing the file's XML"""
+        out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
+        reindent(self.document.getroot(), indent="    ", leaves=('string', 'item'))
+        self.document.write(out, pretty_print=False, xml_declaration=False,
+                            encoding='utf-8', doctype=self._doctype)
+
     def parse(self, xml):
         """Populates this object from the given xml string"""
         if not hasattr(self, 'filename'):
@@ -460,7 +488,7 @@ class AndroidResourceFile(lisa.LISAfile):
             xml.seek(0)
             posrc = xml.read()
             xml = posrc
-        parser = etree.XMLParser(strip_cdata=False)
+        parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
         self.document = etree.fromstring(xml, parser).getroottree()
         self._encoding = self.document.docinfo.encoding
         self.initbody()
@@ -475,13 +503,13 @@ class AndroidResourceFile(lisa.LISAfile):
         target_lang = super(AndroidResourceFile, self).gettargetlanguage()
 
         # If targetlanguage isn't set, we try to extract it from the filename path (if any).
-        if (target_lang is None) and hasattr(self, 'filename') and self.filename:
+        if target_lang is None and hasattr(self, 'filename') and self.filename:
             # Android standards expect resource files to be in a directory named "values[-<lang>[-r<region>]]".
             parent_dir = os.path.split(os.path.dirname(self.filename))[1]
-            match = re.search('^values-(\w*)', parent_dir)
-            if (match is not None):
+            match = re.search(r'^values-(\w*)', parent_dir)
+            if match is not None:
                 target_lang = match.group(1)
-            elif (parent_dir == 'values'):
+            elif parent_dir == 'values':
                 # If the resource file is inside the "values" directory, then it is the default/source language.
                 target_lang = self.sourcelanguage
 
@@ -499,12 +527,28 @@ class AndroidResourceFile(lisa.LISAfile):
         newns = {}
         do_cleanup = False
         if new:
+            # Include any possible new namespaces
             newns = self.body.nsmap
             for ns in unit.xmlelement.nsmap:
                 if ns not in newns:
                     do_cleanup = True
                     newns[ns] = unit.xmlelement.nsmap[ns]
 
+            # Detect if unit is using XML entities
+            hasentity = False
+            for xmlelement in unit.xmlelement.iterdescendants():
+                if xmlelement.tag is etree.Entity:
+                    hasentity = True
+                    break
+
+            # Copy doctype to include possibly new entities
+            if hasentity:
+                cloned_doc = copy.deepcopy(unit._store.document)
+                cloned_doc.getroot().clear()
+                self._doctype = etree.tostring(
+                    cloned_doc, xml_declaration=False, encoding='unicode'
+                ).rsplit('\n', 1)[0]
+
         super(AndroidResourceFile, self).addunit(unit, new)
         # Move aliased namespaces to the <resources> tag
         # The top_nsmap was introduced in LXML 3.5.0
