@@ -26,13 +26,14 @@ import six
 from six.moves import html_parser
 from six.moves.html_entities import name2codepoint
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 from translate.storage.base import ParseError
 
 
 # Override the piclose tag from simple > to ?> otherwise we consume HTML
 # within the processing instructions
-html_parser.piclose = re.compile('\?>')
+html_parser.piclose = re.compile(r'\?>')
 
 
 strip_html_re = re.compile(r'''
@@ -67,7 +68,7 @@ def strip_html(text):
     text = text.strip()
 
     # If all that is left is PHP, return ""
-    result = re.findall('(?s)^<\?.*?\?>$', text)
+    result = re.findall(r'(?s)^<\?.*?\?>$', text)
     if len(result) == 1:
         return ""
 
@@ -77,7 +78,7 @@ def strip_html(text):
     return text
 
 
-normalize_re = re.compile("\s\s+")
+normalize_re = re.compile(r"\s\s+")
 
 
 def normalize_html(text):
@@ -100,16 +101,22 @@ class htmlunit(base.TranslationUnit):
         self.locations = []
         self.source = source
 
-    def getsource(self):
+    @property
+    def source(self):
         #TODO: Rethink how clever we should try to be with html entities.
         text = self._text.replace("&amp;", "&")
         text = text.replace("\r\n", " ").replace("\n", " ").replace("\r", " ")
         return text
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         self._rich_source = None
         self._text = safe_escape(source)
-    source = property(getsource, setsource)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def addlocation(self, location):
         self.locations.append(location)
@@ -186,7 +193,8 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         else:
             self.callback = callback
         self.includeuntaggeddata = includeuntaggeddata
-        html_parser.HTMLParser.__init__(self)
+        htmlargs = {'convert_charrefs': True} if six.PY34 else {}
+        html_parser.HTMLParser.__init__(self, **htmlargs)
 
         if inputfile is not None:
             htmlsrc = inputfile.read()
@@ -196,7 +204,7 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
     def _simple_callback(self, string):
         return string
 
-    ENCODING_RE = re.compile(b'''<meta.*
+    ENCODING_RE = re.compile(br'''<meta.*
                                 content.*=.*?charset.*?=\s*?
                                 ([^\s]*)
                                 \s*?["']\s*?>
@@ -228,14 +236,18 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         The purpose of this is to remove all potential "tag-like" code from
         inside PHP.  The hash looks nothing like an HTML tag, but the following
         PHP::
+
           $a < $b ? $c : ($d > $e ? $f : $g)
+
         looks like it contains an HTML tag::
+
           < $b ? $c : ($d >
+
         to nearly any regex.  Hence, we replace all contents of PHP with simple
         strings to help our regexes out.
 
         """
-        result = re.findall('(?s)<\?(.*?)\?>', text)
+        result = re.findall(r'(?s)<\?(.*?)\?>', text)
         for pi in result:
             pi_escaped = pi.replace("<", "%lt;").replace(">", "%gt;")
             self.pidict[pi_escaped] = pi
@@ -277,7 +289,7 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         if text == '&nbsp;':
             return False
 
-        pattern = '<\?.*?\?>'  # Lazily strip all PHP
+        pattern = r'<\?.*?\?>'  # Lazily strip all PHP
         result = re.sub(pattern, '', text).strip()
         pattern = '<[^>]*>'  # Strip all HTML tags
         result = re.sub(pattern, '', result).strip()
