@@ -86,7 +86,7 @@ def makekey(ookey, long_keys):
     project, sourcefile, resourcetype, groupid, localid, platform = ookey
     sourcefile = sourcefile.replace('\\', '/')
     if long_keys:
-        sourcebase = os.path.join(project, sourcefile)
+        sourcebase = '/'.join((project, sourcefile))
     else:
         sourceparts = sourcefile.split('/')
         sourcebase = "".join(sourceparts[-1:])
@@ -131,7 +131,7 @@ def unescape_text(text):
         .replace("\\r", "\r").replace("\a", "\\\\")
 
 
-helptagre = re.compile('''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
+helptagre = re.compile(r'''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
 
 
 def escape_help_text(text):
