@@ -547,3 +547,50 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         second.addunit(store.units[1], True)
         store = self.StoreClass()
         assert bytes(second) == content
+
+    def test_markup_remove(self):
+        template = '''<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="privacy_policy"><u>Datenschutzerklärung</u></string>
+</resources>'''
+        content = template.encode('utf-8')
+        newcontent = template.replace('<u>', '').replace('</u>', '').encode('utf-8')
+        store = self.StoreClass()
+        store.parse(content)
+        assert bytes(store) == content
+        store.units[0].target = "Datenschutzerklärung"
+        assert bytes(store) == newcontent
+
+    def test_markup_set(self):
+        template = '''<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <!--Multimedia tab-->
+    <string name="id">Multimedia tab</string>
+</resources>'''
+        content = template.encode('utf-8')
+        newcontent = template.replace('>Multimedia tab<', '>Other <b>tab</b><').encode('utf-8')
+        store = self.StoreClass()
+        store.parse(content)
+        assert bytes(store) == content
+        store.units[0].target = "Other <b>tab</b>"
+        assert bytes(store) == newcontent
+
+    def test_edit_plural_others(self):
+        content = '''<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="teststring">
+        <item quantity="one"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> den</item>
+        <item quantity="few"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny</item>
+        <item quantity="many"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
+        <item quantity="other"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
+    </plurals>
+</resources>'''.encode('utf-8')
+        store = self.StoreClass()
+        store.targetlanguage = 'ru'
+        store.parse(content)
+        store.units[0].target = multistring([
+            '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> den',
+            '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny',
+            '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu',
+        ])
+        assert bytes(store) == content
