@@ -2,8 +2,9 @@
 
 from __future__ import unicode_literals
 from io import BytesIO
+from pytest import raises
 from translate.misc.multistring import multistring
-from translate.storage import jsonl10n, test_monolingual
+from translate.storage import base, jsonl10n, test_monolingual
 
 
 JSON_I18NEXT = b"""{
@@ -30,6 +31,14 @@ JSON_I18NEXT_PLURAL = b"""{
     "keyPluralMultipleEgArabic": "Nazdar"
 }
 """
+JSON_ARRAY = b"""{
+    "key": [
+        "One",
+        "Two",
+        "Three"
+    ]
+}
+"""
 
 
 class TestJSONResourceUnit(test_monolingual.TestMonolingualUnit):
@@ -47,6 +56,11 @@ class TestJSONResourceStore(test_monolingual.TestMonolingualStore):
 
         assert out.getvalue() == b'{\n    "key": "value"\n}\n'
 
+    def test_error(self):
+        store = self.StoreClass()
+        with raises(base.ParseError):
+            store.parse('{"key": "value"')
+
     def test_filter(self):
         store = self.StoreClass(filter=['key'])
         store.parse('{"key": "value", "other": "second"}')
@@ -83,6 +97,15 @@ class TestJSONResourceStore(test_monolingual.TestMonolingualStore):
 }
 '''
 
+    def test_bom(self):
+        content = "{}\n".encode("utf-8-sig")
+        store = self.StoreClass()
+        store.parse(content)
+        assert len(store.units) == 0
+        out = BytesIO()
+        store.serialize(out)
+        assert out.getvalue() == content
+
 
 class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
     StoreClass = jsonl10n.JsonNestedFile
@@ -120,6 +143,15 @@ class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
 
         assert out.getvalue() == data
 
+    def test_array(self):
+        store = self.StoreClass()
+        store.parse(JSON_ARRAY)
+
+        out = BytesIO()
+        store.serialize(out)
+
+        assert out.getvalue() == JSON_ARRAY
+
 
 class TestWebExtensionUnit(test_monolingual.TestMonolingualUnit):
     UnitClass = jsonl10n.WebExtensionJsonUnit
@@ -153,6 +185,28 @@ class TestWebExtensionStore(test_monolingual.TestMonolingualStore):
 
         assert out.getvalue() == b'{\n    "key": {\n        "message": "another",\n        "description": "note"\n    }\n}\n'
 
+    def test_placeholders(self):
+        DATA = """{
+    "youCanClose": {
+        "message": "Bravo ! Votre compte $SITE$ est relié à Scrobbly. Vous pouvez fermer et revenir en arrière",
+        "placeholders": {
+            "site": {
+                "content": "$1",
+                "example": "AniList"
+            }
+        }
+    }
+}
+""".encode('utf-8')
+
+        store = self.StoreClass()
+        store.parse(DATA)
+        assert store.units[0].placeholders is not None
+        out = BytesIO()
+        store.serialize(out)
+
+        assert out.getvalue() == DATA
+
 
 class TestI18NextStore(test_monolingual.TestMonolingualStore):
     StoreClass = jsonl10n.I18NextFile
