@@ -1,4 +1,3 @@
-import pytest
 import six
 from lxml import etree
 
@@ -510,3 +509,30 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert bytes(xfile) == xlfsource
         xfile.units[0].addnote('Test note')
         assert bytes(xfile) == xlfsourcenote
+
+    def test_add_target(self):
+        xlfsource = b'''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xlftarget = '''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+      <target>Soubor</target>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xfile = xliff.xlifffile.parsestring(xlfsource)
+        assert bytes(xfile) == xlfsource
+        xfile.units[0].rich_target = [u"Soubor"]
+        assert bytes(xfile).decode('ascii') == xlftarget
