@@ -32,7 +32,7 @@ from translate.lang import data
 from translate.search.lshtein import LevenshteinComparer
 
 
-STRIP_REGEXP = re.compile("\W", re.UNICODE)
+STRIP_REGEXP = re.compile(r"\W", re.UNICODE)
 
 
 class LanguageError(Exception):
@@ -115,7 +115,7 @@ CREATE UNIQUE INDEX IF NOT EXISTS targets_uniq_idx ON targets (sid, text, lang);
         try:
             self.cursor.executescript(script)
             self.connection.commit()
-        except:
+        except Exception:
             self.connection.rollback()
             raise
 
@@ -246,7 +246,7 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
 
             if commit:
                 self.connection.commit()
-        except:
+        except Exception:
             if commit:
                 self.connection.rollback()
             raise
