@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-u"""Manage the Trados .txt Translation Memory format
+r"""Manage the Trados .txt Translation Memory format
 
 A Trados file looks like this:
 
@@ -50,8 +50,15 @@ try:
 except ImportError:
     raise ImportError("BeautifulSoup 4 is not installed. Support for Trados txt is disabled.")
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 
+__all__ = (
+    'TRADOS_TIMEFORMAT', 'RTF_ESCAPES',
+    'escape', 'unescape',
+    'TradosTxtDate', 'TradosUnit', 'TradosTxtTmFile',
+)
+
 
 TRADOS_TIMEFORMAT = "%d%m%Y, %H:%M:%S"
 """Time format used by Trados .txt"""
@@ -151,9 +158,18 @@ class TradosUnit(base.TranslationUnit):
         self._soup = None
         super(TradosUnit, self).__init__(source)
 
-    def getsource(self):
+    @property
+    def source(self):
         return unescape(self._soup.findAll('seg')[0].contents[0])
-    source = property(getsource, None)
+
+    @source.setter
+    def source(self, source):
+        pass
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def gettarget(self):
         return unescape(self._soup.findAll('seg')[1].contents[0])
@@ -163,7 +179,7 @@ class TradosUnit(base.TranslationUnit):
 class TradosSoup(BeautifulSoup):
 
     MARKUP_MASSAGE = [
-        (re.compile('<(?P<fulltag>(?P<tag>[^\s\/]+).*?)>(?P<content>.+)\r'),
+        (re.compile('<(?P<fulltag>(?P<tag>[^\\s\\/]+).*?)>(?P<content>.+)\r'),
          lambda x: '<%(fulltag)s>%(content)s</%(tag)s>' % x.groupdict()),
     ]
 
