@@ -39,32 +39,13 @@ from translate.lang import data
 from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.misc.xml_helpers import reindent
-from translate.storage import base, lisa
+from translate.storage import lisa
 from translate.storage.placeables import general
 from translate.storage.workflow import StateEnum as state
 
 
 # TODO: handle translation types
 
-NPLURALS = {
-    'jp': 1,
-    'en': 2,
-    'fr': 2,
-    'lv': 3,
-    'ga': 3,
-    'cs': 3,
-    'sk': 3,
-    'mk': 3,
-    'lt': 3,
-    'ru': 3,
-    'pl': 3,
-    'ro': 3,
-    'sl': 4,
-    'mt': 4,
-    'cy': 5,
-    'ar': 6,
-}
-
 
 class tsunit(lisa.LISAunit):
     """A single term in the TS file."""
@@ -115,7 +96,10 @@ class tsunit(lisa.LISAunit):
         return self.xmlelement.find(self.namespaced(self.languageNode))
 
     def _gettargetnode(self):
-        return self.xmlelement.find(self.namespaced("translation"))
+        result = self.xmlelement.find(self.namespaced("translation"))
+        if result is not None:
+            return result
+        return etree.SubElement(self.xmlelement, self.namespaced("translation"))
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
@@ -138,9 +122,6 @@ class tsunit(lisa.LISAunit):
     @property
     def target(self):
         targetnode = self._gettargetnode()
-        if targetnode is None:
-            etree.SubElement(self.xmlelement, self.namespaced("translation"))
-            return None
         if self.hasplural():
             numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
             return multistring([data.forceunicode(node.text) or u"" for node in numerus_nodes])
@@ -229,10 +210,7 @@ class tsunit(lisa.LISAunit):
 
     def _gettype(self):
         """Returns the type of this translation."""
-        targetnode = self._gettargetnode()
-        if targetnode is not None:
-            return targetnode.get("type")
-        return None
+        return self._gettargetnode().get("type")
 
     def _settype(self, value=None):
         """Set the type of this translation."""
@@ -500,11 +478,10 @@ class tsfile(lisa.LISAfile):
         return True
 
     def nplural(self):
-        lang = self.header.get("language")
-        if lang in NPLURALS:
-            return NPLURALS[lang]
-        else:
+        lang = data.get_language(self.header.get("language"))
+        if lang is None:
             return 1
+        return lang[1]
 
     def serialize(self, out):
         """Write the XML document to a file."""
